/*
Copyright (c) 2002, 2003, Oliver Tscherwitschke
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*!
 * \file hardware.h
 * \brief Header file for hardware.c
 *
 */

#ifndef HARDWARE_H
#define HARDWARE_H


/*
 * These definitions are only intended for otOS-internal use
 */
#ifdef COMPILE_OTOS
 
/* function prototypes */
void otosInitHardware(void);


/* hardware dependent macros */
#define GET_RAM_BANK() ({                                       \
    uint8_t bank;                                               \
    __asm__ volatile (                                          \
        /* save ram bank */                                     \
        "in %0, %1"         "\n\t"      /* read PORTE */        \
        "andi %0, 0x3c"     "\n\t"      /* mask */              \
        "lsr %0"            "\n\t"      /* >> 2 */              \
        "lsr %0"            "\n\t"                              \
        : "=r" (bank)                                           \
        : "I" (_SFR_IO_ADDR(PORTE))                             \
    );                                                          \
    bank;                                                       \
})

#define SET_RAM_BANK(bank) ({                                   \
    uint8_t tmp;                                                \
    __asm__ volatile (                                          \
        "lsl %1"            "\n\t"      /* << 2 */              \
        "lsl %1"            "\n\t"                              \
        "in %0, %2"         "\n\t"      /* get PORTE */         \
        "andi %0, 0xc3"     "\n\t"      /* mask */              \
        "or %0, %1"         "\n\t"      /* combine */           \
        "out %2, %0"        "\n\t"      /* output */            \
        : "=&r" (tmp)                                           \
        : "r" (bank), "I" (_SFR_IO_ADDR(PORTE))                 \
    );                                                          \
})





#endif /* #ifdef COMPILE_OTOS */

#endif
