/*
Copyright (c) 2002, 2003, Oliver Tscherwitschke
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*!
 * \file message.h
 * \brief Header file for message.c
 *
 */

#ifndef MESSAGE_H
#define MESSAGE_H


#include "types.h"


/* return values */
#define MESSAGE_SUCCESS         0
#define MESSAGE_TIMEOUT         1
#define MESSAGE_QUEUE_EMPTY     2
#define MESSAGE_QUEUE_FULL      3



/*! 
 * \ingroup message
 * \brief An otOS message
 */
typedef union
{
    uint8_t     byte[4];
    uint16_t    word[2];
    uint32_t    dword;
}
OtosMessage;


/* structure for an otOS message queue */
typedef struct
{
    uint8_t         size;       /* size of the message queue        */
    uint8_t         in;         /* index to next message to insert  */
    uint8_t         out;        /* index to next message to read    */
    uint8_t         count;      /* number of messages in queue      */
    OtosMessage     msg[];      /* flexible size array of messages  */
}
OtosMessageQueue;


/* function prototypes */
OtosMessageQueue*       otosCreateMessageQueue(uint8_t Size);
uint8_t                 otosSendMessage(OtosMessageQueue* pQueue, OtosMessage* pMsg);
uint8_t                 otosReceiveMessage(OtosMessageQueue* pQueue, OtosMessage* pMsg, uint32_t Timeout);



/*
 * These definitions are only intended for otOS-internal use
 */
#ifdef COMPILE_OTOS

/* macros */

/* inc out index and dec message count */
#define MQUEUE_INC_OUT(pQ)                  \
    ++pQ->out;                              \
    if (pQ->out == pQ->size) pQ->out = 0;   \
    --pQ->count;

/* inc in index and inc message count */
#define MQUEUE_INC_IN(pQ)                   \
    ++pQ->in;                               \
    if (pQ->in == pQ->size) pQ->in = 0;     \
    ++pQ->count;

#endif /* #ifdef COMPILE_OTOS */

#endif
