/*
Copyright (c) 2002, 2003, Oliver Tscherwitschke
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*!
 * \file mutex.h
 * \brief Header file for mutex.c
 *
 */

 
#ifndef MUTEX_H
#define MUTEX_H


#include "types.h"
#include "task.h"


/*
 * Constants
 */

#define MUTEX_SUCCESS           0
#define MUTEX_ALREADY_LOCKED    1
#define MUTEX_TIMEOUT           2
#define MUTEX_NOT_OWNER         3



/*
 * Types
 */

typedef struct
{
    uint8_t     lock;       /* Lock state. 0: unlocked, 1: locked */
    OtosTask*   pOwner;     /* The task that owns this mutex */
} OtosMutex;




/*
 * function prototypes
 */
 
uint8_t   otosLockMutex(OtosMutex* pMutex, uint32_t timeout);
uint8_t   otosUnlockMutex(OtosMutex* pMutex);


/*
 * These definitions are only intended for otOS-internal use
 */
#ifdef COMPILE_OTOS

inline uint8_t otosTestAndSet(uint8_t* pLock);

#endif /* #ifdef COMPILE_OTOS */


#endif
