/*
Copyright (c) 2002, 2003, Oliver Tscherwitschke
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*!
 * \file otos_cfg.h
 * \brief otOS configuration file
 *
 */

#ifndef OTOS_CFG_H
#define OTOS_CFG_H


/* #defines for easier debugging */
#undef  OTOS_DEBUG_RTC          /* if defined, don't use RTC */
#undef  OTOS_DEBUG_STACK        /* if defined, functions for dumping stack are available */
#undef  OTOS_DEBUG_TASK_QUEUES  /* if defined, functions for dumping task queues are available */

#define OTOS_STACK_CHECK        /* if defined, otOS tries to detect stack overflows */
#undef  OTOS_PROFILING          /* if defined, profiling is available */



/* task properties */
#define PRIO_IDLE   0           /* priority of the idle task must be zero! */
#define STACK_IDLE  128         /* stack size of the idle task */
#define NAME_IDLE   'I'         /* name of the idle task */

#define PRIO_MAIN   128         /* priority of the main task */
#define STACK_MAIN  256         /* stack size of the main task */
#define NAME_MAIN   'M'         /* name of the main task */



/*
 * Target specific memory settings
 */
 
#if defined __AVR_ATmega103__
/*****************************************************************************
 * ATmega103
 */

#define EXTERNAL_RAM_START  0x8000
#define EXTERNAL_RAM_END    0xffff

/* set this to true, if you want otOS to support banking */
#define OTOS_BANKING
#define NUMBER_OF_BANKS 16



#elif defined __AVR_ATmega128__
/*****************************************************************************
 * ATmega128
 */

#define EXTERNAL_RAM_START  0x8000
#define EXTERNAL_RAM_END    0xffff

/* set this to true, if you want otOS to support banking */
#define OTOS_BANKING
#define NUMBER_OF_BANKS 16



#elif defined __AVR_ATmega163__
/*****************************************************************************
 * ATmega163
 */


#elif defined __AVR_ATmega323__
/*****************************************************************************
 * ATmega163
 */

#endif

/* 
 * End of target specific memory settings
 */

#endif
