/*
Copyright (c) 2002, 2003, Oliver Tscherwitschke
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*!
 * \file otos_def.h
 * \brief Global otOS definitions, constants and macros
 *
 */

#ifndef OTOS_DEF_H
#define OTOS_DEF_H


/*! \brief otOS version */
#define OTOS_VERSION    "0.9.0"     /* mayor.minor.release */


/* some generally useful constants */
#define TRUE    1
#define FALSE   0


/*
 * macros
 */


/* get the stack pointer */
#define GET_SP() ({                 \
    uint16_t result;                \
     __asm__ volatile (             \
        "in %A0, %1"    "\n\t"      \
        "in %B0, %2"    "\n\t"      \
        : "=r" (result)             \
        : "I" (_SFR_IO_ADDR(SPL)),  \
          "I" (_SFR_IO_ADDR(SPH))   \
    );                              \
    result;                         \
})
 
/* returns 1 if global interrupt enable bit is set */
#define ISR_ACTIVE() ({         \
    uint8_t t;                  \
    __asm__ volatile (          \
        "clr %0" "\n\t"         \
        "brie L_%=" "\n\t"      \
        "inc %0" "\n"           \
        "L_%=: " "\n\t"         \
        : "=r" (t)              \
        :                       \
    );                          \
    t;                          \
})

/* returns 1 if global interrupt enable bit is not set */
#define ISR_NOT_ACTIVE() ({     \
    uint8_t t;                  \
    __asm__ volatile (          \
        "clr %0" "\n\t"         \
        "brid L_%=" "\n\t"      \
        "inc %0" "\n"           \
        "L_%=: " "\n\t"         \
        : "=r" (t)              \
        :                       \
    );                          \
    t;                          \
})


#endif
