/*
Copyright (c) 2002, 2003, Oliver Tscherwitschke
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*!
 * \file time.h
 * \brief Header file for time.c
 *
 */

/*! 
 * \addtogroup time
 *
 * @{
 */

#ifndef TIME_H
#define TIME_H


/* 
 * constants
 */

/*! \brief Number of otOS system ticks per second */
#define TICKS_PER_SEC   256

#define MS10        (TICKS_PER_SEC / 100)
#define MS20        (TICKS_PER_SEC / 50)
#define MS50        (TICKS_PER_SEC / 20)
#define MS100       (TICKS_PER_SEC / 10)
#define MS125       (TICKS_PER_SEC / 8)
#define MS200       (TICKS_PER_SEC / 5)
#define MS250       (TICKS_PER_SEC / 4)
#define MS500       (TICKS_PER_SEC / 2)
#define MS1000       TICKS_PER_SEC

#define SEC1         TICKS_PER_SEC
#define SEC2        (TICKS_PER_SEC * 2)
#define SEC5        (TICKS_PER_SEC * 5)
#define SEC10       (TICKS_PER_SEC * 10)
#define SEC20       (TICKS_PER_SEC * 20)
#define SEC30       (TICKS_PER_SEC * 30)
#define SEC40       (TICKS_PER_SEC * 40)
#define SEC50       (TICKS_PER_SEC * 50)
#define SEC60       (TICKS_PER_SEC * 60)

#define MIN1        (TICKS_PER_SEC * 60)
#define MIN2        (MIN1 * 2)
#define MIN5        (MIN1 * 5)
#define MIN10       (MIN1 * 10)

#define INFINITE    0xffffffffL



/*
 * function prototypes
 */

inline uint32_t otosGetTicks(void);
void            otosSleep(uint32_t ticks);
void            otosDelay(uint32_t ticks);
inline void     otosSetTickHook(void (*pFunc)(void));
uint32_t        otosGetTickDiff(uint32_t earlier);

#endif

/*! @} */
